@@ -1,6 +1,8 @@
 __author__ = 'Akuukis <akuukis@kalvis.lv>'
 import datetime
+import math
 
+from beancount.core.amount import Amount
 from beancount.core.data import filter_txns
 from beancount.core.number import D
 
@@ -8,14 +10,13 @@ from .common import extract_mark_tx
 from .common import new_whole_entries
 from .common import read_config
 from .common import parse_mark
-from .common import get_number_of_txn
 
 __plugins__ = ['recur']
 
 
 def dublicate_over_period(params, default_date, value, config):
     begin_date, duration, step = parse_mark(params, default_date, config)
-    period = get_number_of_txn(begin_date, duration, step, config['max_new_tx'])
+    period = math.floor( duration / step )
 
     if(period > config['max_new_tx']):
         period = config['max_new_tx']
@@ -23,11 +24,11 @@ def dublicate_over_period(params, default_date, value, config):
 
     dates = []
     amounts = []
-    i = 0
-    while begin_date + i * step < begin_date + duration and begin_date + i * step <= datetime.date.today():
-        amounts.append(D(str(value)))
-        dates.append(begin_date + i * step)
-        i += 1
+    date = begin_date
+    while date < begin_date + datetime.timedelta(days=duration) and date <= datetime.date.today():
+        amounts.append( D(str(value)) )
+        dates.append(date)
+        date = date + datetime.timedelta(days=step)
 
     return (dates, amounts)
 
